@@ -103,7 +103,7 @@ Puppet::Type.type(:pcmk_stonith).provide(:default) do
   end
 
   def stonith_resource_exists?
-    cmd = 'stonith show ' + @resource[:name] + ' > /dev/null 2>&1'
+    cmd = 'stonith ' + pcs_config_or_show() + ' ' + @resource[:name] + ' > /dev/null 2>&1'
     ret = pcs('show', @resource[:name], cmd, @resource[:tries],
               @resource[:try_sleep], @resource[:verify_on_create], @resource[:post_success_sleep])
     if ret == false then
@@ -131,7 +131,8 @@ Puppet::Type.type(:pcmk_stonith).provide(:default) do
 
   def stonith_location_rule_create()
     pcmk_host_list = @resource[:pcmk_host_list]
-    if not_empty_string(pcmk_host_list)
+    nodes_count = crm_node_l().lines.size
+    if not_empty_string(pcmk_host_list) and nodes_count > 1
       location_cmd = "constraint location #{@resource[:name]} avoids #{pcmk_host_list}=10000"
       Puppet.debug("stonith_location_rule_create: #{location_cmd}")
       pcs('create', @resource[:name], location_cmd, @resource[:tries],
